# CopperUI
CopperUI is a python package, which is designed to fix my personal grievances. it changes and shortens syntax to be easier to read, and makes TUI applications easier to write.

<h1>Why CopperUI?</h1>
CopperUI is a python package made for making simple applications and tools in the command line. 

<h1>How does it work?</h1>
CopperUI uses shortcuts to change syntax, but comes with extra packages that I find absolutley necessary for most TUI projects.

<h1>Contributing to the OS community</h1>

**all** projects that use project copperhead features (for now just copperUI) will be featured on this repo. you can be featured by @ing [Morgandri1](https://twitter.com/Morgandri1dev), or [Copperhead Software](https://twitter.com/CopperSoftware) on twitter, making an issue, or creating a discussion on github.

<h1>Features:</h1>

CopperUI makes it easier to make TUI applications, starting with personalization. **all** textual functions include a color, background, and text option. this lets you change the color to match everything. 

CopperApp is a wrapper to help make organizing your apps more easily 

<h1>How to install?</h1>

Through pip:
    <br>``pip install CopperUI``

[LEGACY] Manual build:
    <br>    run setup.py
    <br>    add copperhead.py to root directory of project. (or wherever you want it.)
